
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: AVG = eeg_average_trials(DATA, DIM)
##
## Computes the average matrix AVG of a 3-dimensional array DATA along
## dimension DIM and removes singleton dimensions.
##
## Example:
##
##  param = eeg_set_parameters(19, 200, 200);
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, param, 128);
##  evoked = eeg_average_trials(eegdata);       # compute evoked potentials
##
## See also: eeg_read_dataset

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing evoked-potentials

function avg = eeg_average_trials(data, dim = 1)
  if !ismatrix(data)
    error('argument must be a n-dimensional matrix');
  end
  avg = eeg_remove_singletondims(mean(data, dim));
end


