
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: F = eeg_convolve_trial(DATA, H)
##
## Filters the columns of matrix DATA with convolution kernel H and
## outputs the filtered matrix F.
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 19, 128);  # assume 19 channels
##  kernel = eeg_kernel_gabor(10, 2, 512);       # gabor filter tuned at 10 Hz
##                                               # for a sample rate of 512 Hz
##  filtered = eeg_convolve_trial(eegdata{1}, kernel); # filter first trial
##
## See also: eeg_read_dataset, eeg_kernel_gabor, eeg_kernel_sinusoidal

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function f = eeg_convolve_trial(data, h)
  if !ismatrix(data)
    error('data must be a matrix');
  end
  if ndims(data) != 2
    error('data must be a 2D matrix');
  end
  nk = floor(length(h) / 2);
  data = [data; zeros(nk, size(data)(2))];
  f = fftfilt(h, data);
  f = f((nk + 1):(size(data)(1)), :);
end

