
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: EP = eeg_evoked_power(DATA, PARAM, FREQ, ALPHA, NBINS)
##
## Computes the significant changes in evoked log-power from dataset DATA
## at the frequency bands specified by vector FREQ. PARAM is a parameter
## structure, as returned by eeg_set_parameters. ALPHA is the significance
## threshold and NBINS is the number of bins used to estimate the prestimulus
## distribution (see eeg_significant_changes for details). By default,
## ALPHA = 0.05 and NBINS = 256.
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 19, 128);  # assume 19 channels
##  param = eeg_set_parameters(19, 200, 200);
##  ep = eeg_evoked_power(eegdata, param, 1:10);
##
## See also: eeg_set_parameters, eeg_significant_changes, eeg_read_dataset

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function ep = eeg_evoked_power(data, param, freq, alpha = 0.05, nbins = 256)
  evp = eeg_average_trials(data);
  fevp = eeg_filter_dataset(evp, param, freq);
  amp = eeg_subtract_preavg(eeg_get_amplitude(fevp, 'l'), param);
  ep = eeg_significant_changes(amp, param, alpha, nbins);
end

  