
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: FILES = eeg_find_datafiles(DIR)
##
## Outputs a structure FILES with the names of the .PLG and .WIN
## files found in directory DIR. The structure has the following
## fields: 
## FILES.nfiles is the number of .PLG/.WIN file pairs found
## FILES.plgfiles is a string array that contains the .PLG file names
## FILES.winfiles is a string array that contains the .WIN file names
##
## Example: 
##
##  files = eeg_find_datafiles('data_directory');
##
## See also: eeg_read_dataset

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function f = eeg_find_datafiles(dir)
  f.nfiles = 0;
  f.plgfiles = {};
  f.winfiles = {};
  
  # Read directory and handle possible errors
  [d, err, msg] = readdir(dir);
  if err != 0
    error(msg);
  end
  
  # Loop over all files in directory
  dir = strcat(dir, "/");
  deblank(d);
  for i = 1:length(d)
    # Look for WIN files
    winfile = d{i};
    len = length(winfile);
    if length(winfile) > 4
      if strcmp(tolower(substr(winfile, -4, 4)), ".win")
        # Look for corresponding PLG file
        for j = 1:length(d)
          plgfile = d{j};
          if length(plgfile) == len
            if strcmp(tolower(substr(plgfile, -4, 4)), ".plg")
              if strcmp(substr(plgfile, 1, len - 4), substr(winfile, 1, len - 4))
                # WIN/PLG file pair found - add them to the output structure
                f.nfiles++;
                f.plgfiles{f.nfiles} = strcat(dir, plgfile);
                f.winfiles{f.nfiles} = strcat(dir, winfile);
              end
            end
          end
        end
      end
    end
  end
end

