

## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: OUT = eeg_get_phase(DATA, UNW)
##
## Returns the phase of each element in DATA. DATA can be a matrix,
## or a cell array of matrices, or a cell array of cell arrays of matrices,
## etc. If UNW is true, the phases are unwrapped column-wise (by default,
## UNW is false).
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 20, 128);  # assume 20 channels
##  param = eeg_set_parameters(20, 200, 200, 'elecpos1020');
##  fdata = eeg_filter_dataset(eegdata, 10, param); # filter at 10 Hz
##  phase = eeg_get_phase(fdata);
##
## See also:

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function out = eeg_get_phase(data, unw = false)
  if ismatrix(data)
    if unw
      out = unwrap(angle(data), pi, 1);
    else
      out = angle(data);
    end
  else
    if iscell(data)
      out = cell(size(data));
      for i = 1:rows(data)
        for j = 1:columns(data)
          out{i,j} = eeg_get_phase(data{i,j});
        end
      end
    end
  end
end
