
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: S = eeg_get_syncmatrix(DATA, PARAM, ELECPAIRS)
##
## Converts synchrony data from a vector format (in which each value
## corresponds to an electrode pair, as specified by ELECPAIRS), to a 
## matrix format. The output S will be one dimension higher than DATA.
##
## See also: eeg_synchrony_mpd, eeg_multitoposcope, eeg_compute_synchistogram

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function s = eeg_get_syncmatrix(data, param, elecpairs)
  if !ismatrix(data)
    error('first argument must be a n-dimensional matrix');
  end
  if !ismatrix(elecpairs)
    error('third argument must be an n*2 matrix');
  end
  if columns(elecpairs) != 2
    error('third argument must be an n*2 matrix');
  end
  if rows(elecpairs) != size(data)(ndims(data))
    error('argument sizes are incompatible');
  end
  
  s = zeros([size(data)(1:(ndims(data) - 1)), param.nchan, param.nchan]);
  nd = ndims(s);
  idx.type = "()";
  idx.subs = cell(1, nd);
  for i = 1:nd idx.subs{i} = ":"; end
    
  idx2.type = "()";
  idx2.subs = cell(1, nd - 1);
  for i = 1:(nd - 1) idx2.subs{i} = ":"; end
    
  for e = 1:rows(elecpairs)
    idx.subs{nd - 1} = elecpairs(e, 1);
    idx.subs{nd} = elecpairs(e, 2);
    idx2.subs{nd - 1} = e;
    subsasgn(s, idx, subsref(data, idx2));
  end
end

  