
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: H = eeg_kernel_gabor(FREQ, BW, SR)
##
## Returns the impulse response H of a Gabor filter tuned at
## frequency FREQ (in Hertz) with a bandwidth BW (in Hertz)
## and a sample rate SR (also in Hertz)
##
## Example:
##
##  h = eeg_kernel_gabor(10, 2, 512);
##  y = conv(x, h);

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function h = eeg_kernel_gabor(freq, bw, sr)
        w0 = 2 * pi * freq / sr;
        sw = 2 * pi * bw / sr;
        width = round(4 / sw);  # filter width is approx. 4 / sw
	n = -width:width;
	h = exp(-(sw * n) .^ 2 / 2) .* exp(j * w0 * n) * (sw / sqrt(2 * pi));
end

