
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: eeg_plot_evp(EVP, PARAM, CHANNELS)
##
## Plots the signals in matrix EVP. This function considers
## EVP to be a matrix of evoked potentials and thus labels
## the plot accordingly. The optional arguments PARAM, CHANNELS
## and OPTIONS have the same meaning as in eeg_plot_signals.
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 20, 128);  # assume 20 channels
##  evp = eeg_average_trials(eegdata);
##  eeg_plot_evp(evp);
##
## See also: eeg_plot_signals, eeg_evoked_potentials

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function eeg_plot_evp(evp, param = {}, channels = [], options = {})
  xlab = "Time (samples)";
  ylab = "Potential";
  if !isempty(param)
    xlab = "Time (ms)";
  end
  eeg_plot_signals(evp, param, channels, options);
  title('Evoked potentials');
  xlabel(xlab);
  ylabel(ylab);
end
