
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: eeg_plot_kernel(H, SR)
##
## Plots the frequency and phase response of the filter kernel (impulse
## response) given in vector H. The horizontal scale goes from -SR/2
## to SR/2, where SR is the sample rate. By default, SR = 2*pi.
##
## Example:
##
##  h = eeg_kernel_gabor(10, 2, 200);
##  eeg_plot_kernel(h, 200);
##
## See also: eeg_kernel_gabor, eeg_kernel_sinusoidal

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function eeg_plot_kernel(h, sr = 2 * pi)
	H = fftshift(fft(h));
	w = linspace(-sr/2, sr/2, length(H));
%	subplot(2, 1, 1);
	plot(w, abs(H));
%	subplot(2, 1, 2);
%	plot(w, unwrap(angle(H)));
endfunction

