
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: eeg_plot_signals(S, PARAM, CHANNELS, OPTIONS)
##
## Plots the signals in matrix S. The optional PARAM argument
## contains the EEG parameters as returned by eeg_set_parameters.
## If this argument is given, the plot will be rescaled according
## to PARAM.samplerate and will contain a legend with the electrode
## labels. CHANNELS is an optional vector that contains the indices
## of the columns of S that will be plotted; by default all channels
## are displayed. OPTIONS is a cell array of strings that specify the
## plot options (color, line style, etc.) for each channel (type
## 'help plot' for more details).
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 20, 128);  # assume 20 channels
##  param = eeg_set_parameters(20, 256, 128, 'elecpos1020');
##  eeg_plot_signals(eegdata{1}, param); # plot raw EEG data for trial 1

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function eeg_plot_signals(S, param = {}, channels = [], options = {})
  nt = size(S)(1);
  t = 0:(nt - 1);
  if !isempty(param)
    t = (t - param.tstim) * 1000 / param.samplerate;
  end
  if isempty(channels) 
    channels = 1:size(S)(2);
  end
  plot(t, S(:, channels), options);
  if !isempty(param)
   if (param.tstim > 1) && (param.tstim <= nt)
     hold on
     line([0, 0], [min(min(S)), max(max(S))]);
     if !isempty(param.elecpos)
       labels = [];
       for e = channels 
         labels = [labels; param.elecpos{e}.name]; 
       end
       legend(labels);
     hold off
   end
 end 
end
