
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: eeg_plot_trial(DATA, TRIAL, PARAM, CHANNELS)
##
## Plots the signals in matrix DATA{TRIAL}. This function considers
## DATA to be a cell array of matrices The optional arguments PARAM, \
## CHANNELS and OPTIONS have the same meaning as in eeg_plot_signals.
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 20, 128);  # assume 20 channels
##  eeg_plot_trial(eegdata, 10); # plot trial 10 
##
## See also: eeg_plot_signals, eeg_evoked_potentials

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function eeg_plot_trial(data, trial, param = {}, channels = [], options = {})
  if (trial < 1) || (trial > size(data)(1))
    return;
  end
  xlab = "Time (samples)";
  ylab = "Data";
  if !isempty(param)
    xlab = "Time (ms)";
  end
  eeg_plot_signals(eeg_remove_singletondims(data(trial, :, :)), param, channels, options);
  title(strcat('Data for trial ', int2str(trial)));
  xlabel(xlab);
  ylabel(ylab);
end
