
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: [ECTRIALS, ECID] = eeg_read_datasetsize(FILES, NCHAN, ID)
##
## Determines the ID's of the experimental conditions and the number of
## trials per subject per condition in a TrackWalker file set.
##
## See also: eeg_find_datafiles, eeg_read_subjectdata, eeg_read_dataset

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function [ECTRIALS, ECID, NT] = eeg_read_datasetsize(eegfiles, idi = -1)
  ECTRIALS = zeros(eegfiles.nfiles, 0);
  ECID = [];
  NT = 0;
  
  # Loop over all subjects
  for s = 1:eegfiles.nfiles
    [d, ectrials, ecid, nt] = eeg_read_subjectdata(eegfiles.plgfiles{s}, eegfiles.winfiles{s}, 0, idi);
    if nt > NT
      NT = nt;
    end
    
    # Loop over all EC's
    for i = 1:length(ecid)
      # If id is new, append it to ECID
      id = ecid(i);
      q = find(ECID == id, 1);
      if isempty(q);
        ECID = [ECID, id];
        ECTRIALS = [ECTRIALS, zeros(size(ECTRIALS)(1),1)]; # Add column to ECTRIALS
        q = length(ECID);
      end
      
      ECTRIALS(s,q) = ectrials(i); # Add row to ECTRIALS
    end
  end  
end
