
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: EPOS = EEG_READ_ELECPOS(EPFILE)
##
## Reads electrode label and location data from the file specified by
## EPFILE and returns it as cell array EPOS. Each element of EPOS is a
## structure with fields {name, x, y}, where name specifies the electrode
## label, and (x, y) is the 2D electrode position within a circunference
## of radius 1 with the nose pointing upwards. The file is simply a text
## file with the format:
##
##    name1   x1   y1
##    name2   x2   y2
##    ...
##
## For an example see the file elecpos1020.
##
## Example:
##
##  elecpos = eeg_read_elecpos('elecpos1020');
##
## See also: eeg_set_parameters

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function epos = eeg_read_elecpos(epfile)
  [fid, msg] = fopen(epfile, 'rt');
  if (fid < 0) error(msg); end
  nc = 0;
  while !feof(fid)
    [name, x, y] = fscanf(fid, '%s%f%f', 'C');
    if !feof(fid)
      nc++;
      epos{nc}.name = name;
      epos{nc}.x = x;
      epos{nc}.y = y;
    end
  end
  fclose(fid);
end

  