
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: IMG = eeg_scale_image(X, NEWSIZE, MAP, INTERP)
##
## Resamples an image X in indexed or RGB format from its original size
## to the size specified in the 2-element vector NEWSIZE. If the image
## is in indexed format, the color map is given in MAP. The optional
## argument INTERP specifies the interpolation method (the default is
## 'nearest') - see interp2 for details. The resulting image IMG is
## always in RGB format.
##
## See also: interp2, eeg_tft_map

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function newimg = eeg_scale_image(x, newsize, map = [], interp = 'nearest')
  rgbold = x;
  if ismatrix(map)
    if columns(map) == 3
      rgbold = ind2rgb(x, map);
    end
  end
  xi = linspace(1, size(rgbold)(2), newsize(2));
  yi = linspace(1, size(rgbold)(1), newsize(1));
  [xi, yi] = meshgrid(xi, yi);
  rgbnew = zeros([newsize, 3]);
  rgbnew(:,:,1) = interp2(eeg_remove_singletondims(rgbold(:,:,1)), xi, yi, interp);
  rgbnew(:,:,2) = interp2(eeg_remove_singletondims(rgbold(:,:,2)), xi, yi, interp);
  rgbnew(:,:,3) = interp2(eeg_remove_singletondims(rgbold(:,:,3)), xi, yi, interp);
  newimg = rgbnew;
end
