
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: PARAM = eeg_set_parameters(NCHAN, SR, TSTIM, EPFILE)
##
## Returns the following structure
##  { 
##      nchan = NCHAN,       ## number of channels/electrodes
##      samplerate = SR,     ## sample rate in Hz
##      tstim = TSTIM,       ## stimulus onset time (in samples)
##      elecpos = eeg_read_elecpos(EPFILE),      ## electrode position structure
##      bandwidth = 1,       ## default bandwidth of filters (defaults to 1 Hz)
##      filtertype = 'g'     ## filter type: 'g' = gabor, 's' = sinusoidal
##  }
##
## Example:
##
##  param = eeg_set_parameters(20, 512, 256, 'elecpos1020');
##
## See also: eeg_read_elecpos

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing

function p = eeg_set_parameters(nchan, sr, tstim = 0, epfile = '') 
  p.nchan = nchan;
  p.samplerate = sr;
  p.tstim = tstim;
  p.bandwidth = 2;
  p.filtertype = 'g';
  if strcmp(epfile, '') 
    p.elecpos = {}; 
  else 
    p.elecpos = eeg_read_elecpos(epfile); 
    if length(p.elecpos) != p.nchan
      printf("warning: mismatching number of channels in file %s\n", epfile);
    end
  end
end

