
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: OUT = eeg_subtract_preavg(DATA, PARAM, TDIM);
##
## Subtracts the pre-stimulus average from each signal in a
## dataset DATA and returns the resulting dataset in OUT.
## DATA can be either a matrix or a cell array of matrices.
## PARAM is a parameter structure as returned by eeg_set_parameters.
## The time dimension is considered to be dimension TDIM, which by
## default is equal to ndims(DATA) - 1.
##
## Example:
##
##  files = eeg_find_datafiles('data_directory');
##  eegdata = eeg_read_dataset(files, 19, 128);  # assume 19 channels
##
## See also: eeg_read_dataset

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function out = eeg_subtract_preavg(data, param, dim = 0)
  if !ismatrix(data)
    error('first argument must be a matrix');
  end

  if dim < 1
    dim = ndims(data) - 1;
  end

  skip = round(3 * param.samplerate / (2 * pi * param.bandwidth)); # filter width
  if skip >= param.tstim / 3
    skip = param.tstim / 3;
  end
  prestim = (1 + skip):(param.tstim - skip);
  repsize = ones(1, ndims(data));
  repsize(dim) = size(data)(dim);
  idx.type = "()";
  idx.subs = cell(1,ndims(data));
  for d = 1:ndims(data)
    if d == dim
      idx.subs{d} = prestim;
    else
      idx.subs{d} = ":";
    end
  end
  out = data - repmat(mean(subsref(data, idx), dim), repsize);
end
