
## Copyright (C) 2007 - Alfonso Alba
## 
## This file is part of OctavEEG, an EEG processing library for GNU Octave
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

## Usage: TABLE = eeg_voronoi_partition(PARAM, SIZE, RADIUS, CENTER)
##
## Generates a Voronoi partition image TABLE in which each pixel is labeled
## according to the nearest electrode. The electrode positions are specified
## in the structure PARAM (see eeg_set_parameters for details). The electrodes
## are relocated to a circunference of given RADIUS and CENTER=[CY,CX] within
## an image of size SIZE*SIZE. By default, RADIUS = 0.4 * min(SIZE), and
## CENTER = SIZE/2.
##
## This function is used to render head diagrams, multitoposcopes, and TFT maps.
##
## See also: eeg_head_diagram, eeg_tft_map

## Author: Alfonso Alba <fac@galia.fc.uaslp.mx>
## Keywords: OctavEEG eeg signal-processing


function table = eeg_voronoi_partition(param = {}, tsize, radius, center)
  if isscalar(tsize)
    tsize = [tsize, tsize];
  end
  table = zeros(tsize);
  if nargin() < 4 center = tsize / 2; end
  if nargin() < 3 radius = 0.4 * min(tsize); end
  if isempty(param) param = eeg_set_parameters(19, 0, 0, 'elecpos1020'); end
  if isempty(param.elecpos) param = eeg_set_parameters(19, 0, 0, 'elecpos1020'); end
  nelec = min(length(param.elecpos), param.nchan);
  d = zeros(1,nelec);
  ex = -ones(nelec, 2);
  ey = -ones(nelec, 2);
  for e = 1:nelec
    ex(e,1) = param.elecpos{e}.x;
    ey(e,1) = param.elecpos{e}.y;
  end
  px = [ones(1,tsize(2)); ((1:(tsize(2))) - center(2)) / radius];
  py = [ones(1,tsize(1)); ((1:(tsize(1))) - center(1)) / radius];
  dx2 = (ex * px).^2;
  dy2 = (ey * py).^2;
  for y = 1:(tsize(1))
    dsquared = dx2 + repmat(dy2(:,y), 1, tsize(2));
    [m, table(y,:)] = min(dsquared);
  end
end

